nbqol.outputs.capture
=====================

.. automodule:: nbqol.outputs.capture

   
   .. rubric:: Functions

   .. autosummary::
   
      capture_output
      contextmanager
      create_print_capture
   
   .. rubric:: Classes

   .. autosummary::
   
      AllCaptureHandler
      CapturedLogs
      CapturedOutput
      OutputCapture
      ThreadSafeStringIO
   